BoxE
====

.. currentmodule:: pykeen.models

.. autoclass:: BoxE
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~BoxE.hpo_default
      ~BoxE.loss_default_kwargs

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: loss_default_kwargs
